# 特别感谢

## 平台以及创作者

感谢 [bilibili](https://www.bilibili.com/) 平台以及平台上无数优质内容的创作者。

## 依赖项目

我的正常运作离不开以下项目的支持

- [FFmpeg](https://github.com/FFmpeg/FFmpeg) 用于视频的合并
- [biliass](https://github.com/yutto-dev/yutto/tree/main/packages/biliass) 用于 XML 弹幕转换为 ASS 弹幕
- [VitePress](https://github.com/vuejs/vitepress) 本文档的生成器

## 参考项目

我在探索过程中得到了以下项目的帮助

- 基本结构：<https://github.com/yutto-dev/bilili>
- 协程下载：<https://github.com/changmenseng/AsyncBilibiliDownloader>
- 弹幕转换：<https://github.com/yutto-dev/yutto/tree/main/packages/biliass>
- 样式设计：<https://github.com/willmcgugan/rich>

## 云服务

- [Vercel](https://vercel.com/) 提供[文档托管](https://vercel.com/siguremo/yutto-docs)

## 贡献者

感谢每一位贡献者的辛勤付出

<Contributors owner="yutto-dev" repo="yutto" />

## 赞助者

感谢各位赞助者的资金援助

<GitHubUser username="Uc207Pr4f57t9-251"/>
<GitHubUser username="abc1763613206"/>
<GitHubUser username="Ainavo"/>
<GitHubUser username="vaxl029"/>
<GitHubUser username="aheadlead"/>
<GitHubUser username="symant233"/>
<GitHubUser username="Nightingale0504"/>

## 以及你的支持～

<script setup lang="ts">
import GitHubUser from '../.vitepress/theme/components/GitHubUser.vue'
import Contributors from '../.vitepress/theme/components/Contributors.vue'
</script>
